@@ -1,19 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 1999-2006 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 1999-2006 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kioclient.h"
@@ -27,8 +15,8 @@
 #ifndef KIOCORE_ONLY
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <KPropertiesDialog>
-#include <KRun>
 #include <KService>
 #endif
 #include <KAboutData>
@@ -53,7 +41,7 @@ static QUrl makeURL(const QString &urlArg)
 static QList<QUrl> makeUrls(const QStringList &urlArgs)
 {
     QList<QUrl> ret;
-    foreach (const QString &url, urlArgs) {
+    for (const QString &url : urlArgs) {
         ret += makeURL(url);
     }
     return ret;
@@ -207,18 +195,6 @@ int main(int argc, char **argv)
     return client.doIt(parser) ? 0 /*no error*/ : 1 /*error*/;
 }
 
-static bool krun_has_error = false;
-
-void ClientApp::delayedQuit()
-{
-#ifndef KIOCORE_ONLY
-    // don't access the KRun instance later, it will be deleted after calling slots
-    if (static_cast<const KRun *>(sender())->hasError()) {
-        krun_has_error = true;
-    }
-#endif
-}
-
 static void checkArgumentCount(int count, int min, int max)
 {
     if (count < min) {
@@ -243,18 +219,19 @@ bool ClientApp::kde_open(const QString &url, const QString &mimeType, bool allow
         info.url.setQuery(q);
     }
 
-    if (mimeType.isEmpty()) {
-        KRun *run = new KRun(info.url, nullptr);
-        run->setRunExecutables(allowExec);
-
-        run->setFollowRedirections(false);
-        QObject::connect(run, &KRun::finished, this, &ClientApp::delayedQuit);
-        QObject::connect(run, &KRun::error, this, &ClientApp::delayedQuit);
-        qApp->exec();
-        return !krun_has_error;
-    } else {
-        return KRun::runUrl(info.url, mimeType, nullptr, KRun::RunFlags(KRun::RunExecutables));
-    }
+    auto *job = new KIO::OpenUrlJob(info.url, mimeType);
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+    job->setRunExecutables(allowExec);
+    job->setFollowRedirections(false);
+    bool job_had_error = false;
+    QObject::connect(job, &KJob::result, this, [&](KJob *job) {
+        if (job->error()) {
+            job_had_error = true;
+        }
+    });
+    job->start();
+    qApp->exec();
+    return !job_had_error;
 }
 #endif
 
